@@ -1,6 +1,6 @@
 package Tangerine::hook::require;
 {
-  $Tangerine::hook::require::VERSION = '0.10';
+  $Tangerine::hook::require::VERSION = '0.11';
 }
 use strict;
 use warnings;
@@ -17,7 +17,7 @@ sub run {
         my $module = $s->[1];
         return Tangerine::HookData->new(
             modules => { $module => Tangerine::Occurence->new },
-            ) unless $module =~ /^v?5\..*$/;
+            ) unless $module =~ /^v?5(\..*)?$/;
     }
     return;
 }
